<div class="sheet" lang="zh-tw">
    <div class="badge-face badge-topleft">
        {% include "badges/snippets/top.html" %}
    </div>
    <div class="badge-face badge-topright">
        {% include "badges/snippets/top.html" %}
    </div>
    <div class="badge-mid badge-midleft">
        {% include "badges/snippets/midleft.html" %}
    </div>
    <div class="badge-mid badge-midright">
        {% include "badges/snippets/midright.html" %}
    </div>
    <div class="badge-bottom">
        {% include "badges/snippets/bottom.html" %}
    </div>
</div>
